==> crisis-management-resources-v0.2-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/CarProviderEvent_WSOUIService.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import com.petalslink.wsn.service.wsnproducer.NotificationProducer;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.AbstractExchangeProcessor;
import org.petalslink.easiestdemo.wsoui.provided.Exchange;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIService;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;
import javax.xml.ws.WebServiceFeature;
import javax.xml.ws.Service;

@WebServiceClient(
	wsdlLocation = "crisis/v3/./carProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	name = "carProviderEvent")
public class CarProviderEvent_WSOUIService extends Service implements WSOUIService{

	private static URL WSDL_LOCATION;
	public final static QName SERVICE = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "carProviderEvent");
	public final static QName CarProviderEventPort = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "carProviderEvent");
	
	public static URL getWSDL_LOCATION() {
	  if(WSDL_LOCATION == null) {
	    WSDL_LOCATION = Thread.currentThread().getContextClassLoader().getResource("crisis/v3/carProvider.wsdl");
	    if(WSDL_LOCATION == null) {
	       throw new RuntimeException("Impossible to find wsdl in class loader at: crisis/v3/carProvider.wsdl");
	    } else {
	       System.out.println("WSDL localized at: " + WSDL_LOCATION + "");
	    }
	  }
	  return WSDL_LOCATION;
	}
	public CarProviderEvent_WSOUIService() {
		super(getWSDL_LOCATION(), SERVICE);
	}

	@WebEndpoint(name = "carProviderEventPort")
	public NotificationProducer getCarProviderEventPort() {
	    return super.getPort(CarProviderEventPort, NotificationProducer.class);
	}
	
	
	@WebEndpoint(name = "carProviderEventPort")
	public NotificationProducer getFiremenSOAP(WebServiceFeature... features) {
	    return super.getPort(CarProviderEventPort, NotificationProducer.class, features);
	}
	
	
	public URL getWsdlLocation() {
	    return WSDL_LOCATION;
	}

}

==> crisis-management-resources-v0.4-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/CarProviderEvent_WSOUIService.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import com.petalslink.wsn.service.wsnproducer.NotificationProducer;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.AbstractExchangeProcessor;
import org.petalslink.easiestdemo.wsoui.provided.Exchange;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIService;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;
import javax.xml.ws.WebServiceFeature;
import javax.xml.ws.Service;

@WebServiceClient(
	wsdlLocation = "crisis/management/generated/./carProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	name = "carProviderEvent")
public class CarProviderEvent_WSOUIService extends Service implements WSOUIService{

	private static URL WSDL_LOCATION;
	public final static QName SERVICE = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "carProviderEvent");
	public final static QName CarProviderEventPort = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "carProviderEvent");
	
	public static URL getWSDL_LOCATION() {
	  if(WSDL_LOCATION == null) {
	    WSDL_LOCATION = Thread.currentThread().getContextClassLoader().getResource("crisis/management/generated/carProvider.wsdl");
	    if(WSDL_LOCATION == null) {
	       throw new RuntimeException("Impossible to find wsdl in class loader at: crisis/management/generated/carProvider.wsdl");
	    } else {
	       System.out.println("WSDL localized at: " + WSDL_LOCATION + "");
	    }
	  }
	  return WSDL_LOCATION;
	}
	public CarProviderEvent_WSOUIService() {
		super(getWSDL_LOCATION(), SERVICE);
	}

	@WebEndpoint(name = "carProviderEventPort")
	public NotificationProducer getCarProviderEventPort() {
	    return super.getPort(CarProviderEventPort, NotificationProducer.class);
	}
	
	
	@WebEndpoint(name = "carProviderEventPort")
	public NotificationProducer getFiremenSOAP(WebServiceFeature... features) {
	    return super.getPort(CarProviderEventPort, NotificationProducer.class, features);
	}
	
	
	public URL getWsdlLocation() {
	    return WSDL_LOCATION;
	}

}
